from setuptools import setup
from setuptools import find_packages

setup(
      name='niuzepeng',
      version='1.0.2',
      description='This is my first create!',
      author='Niuzepeng',
      author_email='18217127859@163.com',
      url="https://github.com/zepen",
      license='MIT',
      packages=find_packages(),
      zip_safe=False
)
